@@ -79,8 +79,23 @@ class SynapseStorage(BaseStorage):
 
         self.syn = self.login(token, access_token, input_token)
         self.project_scope = project_scope
+
+
+        # check if "master_fileview" has been set
+        try: 
+            self.storageFileview = CONFIG["synapse"]["master_fileview"]
+        except KeyError: 
+            raise MissingConfigValueError(("synapse", "master_fileview"))
+
+        # check if "manifest_basename" has been set
+        try: 
+            self.manifest = CONFIG["synapse"]["manifest_basename"]
+        except KeyError: 
+            raise MissingConfigValueError(("synapse", "manifest_basename"))
+
         try:
             self.storageFileview = CONFIG["synapse"]["master_fileview"]
+            self.manifest = CONFIG["synapse"]["manifest_basename"]
             if self.project_scope:
                 self.storageFileviewTable = self.syn.tableQuery(
                     f"SELECT * FROM {self.storageFileview} WHERE projectId IN {tuple(self.project_scope + [''])}"
@@ -90,17 +105,10 @@ class SynapseStorage(BaseStorage):
                 self.storageFileviewTable = self.syn.tableQuery(
                     "SELECT * FROM " + self.storageFileview
                 ).asDataFrame()
-
-            self.manifest = CONFIG["synapse"]["manifest_basename"]
-        
-        except KeyError:
-            raise MissingConfigValueError(("synapse", "master_fileview"))
         except AttributeError:
             raise AttributeError("storageFileview attribute has not been set.")
         except SynapseHTTPError:
             raise AccessCredentialsError(self.storageFileview)
-        except ValueError:
-            raise MissingConfigValueError(("synapse", "master_fileview"))
 
     @staticmethod
     def login(token=None, access_token=None, input_token=None):
@@ -138,7 +146,7 @@ class SynapseStorage(BaseStorage):
                 return method(*args, **kwargs)
             except(SynapseHTTPError) as ex:
                 str_message = str(ex).replace("\n","")
-                if 'missing' in str_message:
+                if 'trash' in str_message or 'does not exist' in str_message:
                     logging.warning(str_message)
                     return None
                 else:
@@ -717,16 +725,16 @@ class SynapseStorage(BaseStorage):
 
         return df, results
 
-    def _get_tables(self) -> List[Table]:
-        project = self.syn.get(self.project_scope[0])
+    def _get_tables(self, datasetId: str = None) -> List[Table]:
+        project = self.syn.get(self.getDatasetProject(datasetId))
         return list(self.syn.getChildren(project, includeTypes=["table"]))
 
-    def get_table_info(self) -> List[str]:
+    def get_table_info(self, datasetId: str = None) -> List[str]:
         """Gets the names of the tables in the schema
         Returns:
             list[str]: A list of table names
         """
-        tables = self._get_tables()
+        tables = self._get_tables(datasetId)
         if tables:
             return {table["name"]: table["id"] for table in tables}
         else: 
@@ -735,7 +743,7 @@ class SynapseStorage(BaseStorage):
     @missing_entity_handler
     def upload_format_manifest_table(self, se, manifest, datasetId, table_name, restrict, useSchemaLabel):
         # Rename the manifest columns to display names to match fileview
-        table_info = self.get_table_info()
+        table_info = self.get_table_info(datasetId)
 
         blacklist_chars = ['(', ')', '.', ' ']
         manifest_columns = manifest.columns.tolist()
@@ -1413,7 +1421,7 @@ class SynapseStorage(BaseStorage):
                 # remove rows
                 self.syn.delete(existing_results)
                 # wait for row deletion to finish on synapse before getting empty table
-                sleep(1)
+                sleep(10)
                 
                 # removes all current columns
                 current_table = self.syn.get(existingTableId)
